@@ -74,5 +74,6 @@ class Tipo(Log):
     descricao = models.TextField(null=True)
 
     class Meta:
-        db_table = u'"core\".\"tipo"'
+        #db_table = u'"core\".\"tipo"'
+        # db_table = u'"tipo"'
         unique_together = ('codigo', 'tipo')
