@@ -8,7 +8,8 @@ class Filial(core.models.Log):
     cnpj = models.CharField(max_length=200, null=True)
 
     class Meta:
-        db_table = u'"core\".\"filial"'
+        #db_table = u'"core\".\"filial"'
+        db_table = u'"filial"'
 
 
 class Servico(core.models.Log):
@@ -17,7 +18,8 @@ class Servico(core.models.Log):
     filial = models.ManyToManyField(Filial, through='RelacaoServicos')
 
     class Meta:
-        db_table = u'"core\".\"filial_servico"'
+        #db_table = u'"core\".\"filial_servico"'
+        db_table = u'"filial_servico"'
 
 
 class RelacaoServicos(core.models.Log):
@@ -25,5 +27,6 @@ class RelacaoServicos(core.models.Log):
     servico = models.ForeignKey(Servico, on_delete=models.CASCADE)
 
     class Meta:
-        db_table = u'"core\".\"filial_relacaoservico"'
+        #db_table = u'"core\".\"filial_relacaoservico"'
+        db_table = u'"filial_relacaoservico"'
         unique_together = ('filial', 'servico')
\ No newline at end of file
