@@ -11,4 +11,5 @@ class Log(core.models.Log):
     session_id = models.CharField(max_length=200, null=True)
 
     class Meta:
-        db_table = u'"log\".\"log"'
+        #db_table = u'"log\".\"log"'
+        db_table = u'"log"'
\ No newline at end of file
