@@ -8,11 +8,12 @@ class Profile(AbstractUser, core.models.Log):
     nm_completo = models.CharField(max_length=200, null=True)
 
     tipo_codigo = models.CharField(null=True, max_length=200)
-    tipo_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE.TIPO', related_name='usr_profile_tipo')
-    tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.SET_NULL, null=True, related_name='tipo', to_fields={
+    tipo_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE.TIPO')
+    tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.SET_NULL, null=True, related_name='usr_profile_tipo', to_fields={
         "codigo": "tipo_codigo",
         "tipo": "tipo_tipo"
     })
 
     class Meta:
-        db_table = u'"core\".\"profile"'
\ No newline at end of file
+        #db_table = u'"core\".\"profile"'
+        db_table = u'"profile"'
\ No newline at end of file
